%define module	setuptools

%bcond_with tests
# This controls whether setuptools is build as a wheel or not,
# simplifying Python 3.4 bootstraping process
%bcond_without wheel

# Force python3 build - required for new hplip
# % {?build_python3}%{?!build_python3:%bcond_without python3}
%bcond_without python3

%if %{with wheel}
%define python2_wheelname %{module}-%{version}-py2.py3-none-any.whl
%define python2_record %{py_puresitedir}/%{module}-%{version}.dist-info/RECORD
%define python3_wheelname %{python2_wheelname}
%define python3_record %{py3_puresitedir}/%{module}-%{version}.dist-info/RECORD
%endif
 
Summary:	Easily build and distribute Python packages
Name:		python-%{module}
Version:	18.6.1
Release:	1
Epoch:		1
License:	Python or ZPLv2.0
Group:		Development/Python
Url:		http://pypi.python.org/pypi/%{module}
Source0:	http://pypi.python.org/packages/source/s/setuptools/setuptools-%{version}.tar.gz

BuildArch:	noarch
BuildRequires:	python-devel
%if %{with wheel}
BuildRequires:  python-pip
BuildRequires:  python-wheel
%endif
Provides:	pythonegg(setuptools)
Provides:	pythonegg(distribute)

# For unittests
BuildRequires:	subversion
Requires:	python-pkg-resources

%rename		python-setuptools-devel
%rename		python-distribute

%description
A collection of enhancements to the Python distutils that allow 
you to more easily build and distribute Python packages, especially 
ones that have dependencies on other packages.

%package -n python-pkg-resources
Summary: Runtime module to access python resources
Group:		Development/Python

%description -n python-pkg-resources
Module used to find and manage Python package/version dependencies and access
bundled files and resources, including those inside of zipped .egg files.


%if %{with python3}
%package -n python3-%{module}
Summary:	Easily build and distribute Python3 packages
Group:		Development/Python

BuildRequires:	python3-devel
%if %{with wheel}
BuildRequires:  python3-pip
BuildRequires:  python3-wheel
%endif
Provides:	python3egg(setuptools)
Provides:	python3egg(distribute)
Requires:	python3-pkg-resources

%rename		python3-setuptools-devel
%rename		python3-distribute

%description -n python3-setuptools
A collection of enhancements to the Python 3 distutils that allow
you to more easily build and distribute Python 3 packages, especially
ones that have dependencies on other packages.

%package -n python3-pkg-resources
Summary: Runtime module to access python 3 resources
Group:		Development/Python

%description -n python3-pkg-resources
Module used to find and manage Python 3 package/version dependencies and access
bundled files and resources, including those inside of zipped .egg files.

%endif

%prep
%setup -q -c

mv %{module}-%{version} python2
%if %{with python3}
cp -r python2 python3
%endif

find -name '*.txt' -exec chmod -x \{\} \;
find . -name '*.orig' -exec rm \{\} \;

%if %{with python3}
pushd python3
for file in setuptools/command/easy_install.py ; do
    sed -i '1s|^#!python|#!python3|' $file
done
popd
%endif

%build
pushd python2
%if %{with wheel}
python setup.py bdist_wheel
%else
CFLAGS="%{optflags}" python setup.py build
%endif
popd

%if %{with python3}
pushd python3
%if %{with wheel}
python3 setup.py bdist_wheel
%else
CFLAGS="%{optflags}" python3 setup.py build
%endif
popd
%endif

%install
# Must do the python3 install first because the scripts in /usr/bin are
# overwritten with every setup.py install (and we want the python2 version
# to be the default for now).
%if %{with python3}
pushd python3
%if %{with wheel}
pip3 install -I dist/%{python3_wheelname} --root %{buildroot} --strip-file-prefix %{buildroot}

# TODO: we have to remove this by hand now, but it'd be nice if we wouldn't have to
# (pip install wheel doesn't overwrite)
rm %{buildroot}%{_bindir}/easy_install

sed -i '/\/usr\/bin\/easy_install,/d' %{buildroot}%{python3_record}
%else
python3 setup.py install --skip-build --root %{buildroot}
%endif

rm -rf %{buildroot}%{py3_puresitedir}/setuptools/tests
%if %{with wheel}
sed -i '/^setuptools\/tests\//d' %{buildroot}%{python3_record}
%endif

find %{buildroot}%{py3_puresitedir} -name '*.exe' | xargs rm -f
chmod +x %{buildroot}%{py3_puresitedir}/setuptools/command/easy_install.py
popd

%endif

pushd python2
%if %{with wheel}
pip2 install -I dist/%{python2_wheelname} --root %{buildroot} --strip-file-prefix %{buildroot}
%else
python setup.py install --skip-build --root %{buildroot}
%endif

rm -rf %{buildroot}%{py_puresitedir}/setuptools/tests
%if %{with wheel}
sed -i '/^setuptools\/tests\//d' %{buildroot}%{python2_record}
%endif

find %{buildroot}%{py_puresitedir} -name '*.exe' | xargs rm -f
chmod +x %{buildroot}%{py_puresitedir}/setuptools/command/easy_install.py
popd

%if %{with tests}
%check
pushd python2
python setup.py test
popd

%if %{with python3}
pushd python3
python3 setup.py test
popd
%endif

%endif

%files
%doc python2/*.txt python2/docs
%{_bindir}/easy_install
%{_bindir}/easy_install-2.*
%{py_puresitedir}/*
%exclude %{py_puresitedir}/pkg_resources*

%files -n python-pkg-resources
%{py_puresitedir}/pkg_resources*

%if %{with python3}
%files -n python3-setuptools
%doc python3/*.txt python3/docs
%{_bindir}/easy_install-3.*
%{py3_puresitedir}/*
%exclude %{py3_puresitedir}/pkg_resources*
# %exclude %{py3_puresitedir}/__pycache__/pkg_resources.cpython-*.py*

%files -n python3-pkg-resources
%{py3_puresitedir}/pkg_resources*
# %{py3_puresitedir}/__pycache__/pkg_resources.cpython-*.py*
%endif

%changelog

* Mon Dec 28 2015 dsilakov <denis.silakov@rosalab.ru> 1:18.6.1-1
- (739f136) Merge pull request #1 from import/python-setuptools:auto_update
- (739f136) Updated to 18.6.1 (by updates_builder)


